WidgetDiscoveryAnalytics class

Analytics about widget discovery

Constructors

WidgetDiscoveryAnalytics({required int totalTrackedWidgets, required int totalBugMarkers, required int unresolvedBugs, required int totalSensitiveWidgets, required DateTime lastCleanup})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lastCleanup DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBugMarkers int
final
totalSensitiveWidgets int
final
totalTrackedWidgets int
final
unresolvedBugs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited